4.1.0 (2023-07-05)
==================
🎉 New features
---------------

- add new option "receives-base-url-path" set to True by default. This option will be
  used by :code:`cubicweb_web` 1.1.0 and some other cubes. It indicates CubicWeb to
  take into account an url path if it's defined in the base-url option (for
  example "my-prefix" in :code:`base-url = https://my-website.com/my-prefix/`)
  This will remove the need to do url rewriting in nginx/apache or similar tools.

👷 Bug fixes
------------

- config: catch ImportError instead of ModuleNotFoundError
- tests: automatically add BASE_URL to urls if it's missing

📝 Documentation
----------------

- simplify installation doc and move source installation to contributing part
- fix a lot of sphinx typos in 4.0 changelog

🤷 Various changes
------------------

- remove windmill tutorial (#746.)
- update the museum tutorial to use cubicweb 4
